pub struct DebugConfigLockToml {
pub export_dir: Option<AbsolutePathBuf>,
pub load_path: Option<AbsolutePathBuf>,
pub allow_codex_version_mismatch: Option<bool>,
pub save_fields_resolved_from_model_catalog: Option<bool>,
}Fields
export_dir: Option<AbsolutePathBuf>Directory where Codex writes effective session config lock files.
load_path: Option<AbsolutePathBuf>Lockfile to replay as the authoritative effective config.
allow_codex_version_mismatch: Option<bool>Allow replaying a lock generated by a different Codex version.
save_fields_resolved_from_model_catalog: Option<bool>Save fields resolved from the model catalog/session configuration.