pub struct RealtimeConfig {
pub version: RealtimeWsVersion,
pub session_type: RealtimeWsMode,
pub transport: RealtimeTransport,
pub voice: Option<RealtimeVoice>,
}Fields
version: RealtimeWsVersionsession_type: RealtimeWsModetransport: RealtimeTransportvoice: Option<RealtimeVoice>Trait Implementations
Sourceimpl Clone for RealtimeConfig
impl Clone for RealtimeConfig
Sourcefn clone(&self) -> RealtimeConfig
fn clone(&self) -> RealtimeConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RealtimeConfig
impl Debug for RealtimeConfig
Sourceimpl Default for RealtimeConfig
impl Default for RealtimeConfig
Sourcefn default() -> RealtimeConfig
fn default() -> RealtimeConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RealtimeConfig
impl<'de> Deserialize<'de> for RealtimeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RealtimeConfig
Sourceimpl JsonSchema for RealtimeConfig
impl JsonSchema for RealtimeConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RealtimeConfig
impl PartialEq for RealtimeConfig
Sourceimpl Serialize for RealtimeConfig
impl Serialize for RealtimeConfig
impl StructuralPartialEq for RealtimeConfig