pub enum ConfigLayerSource {
Mdm {
domain: String,
key: String,
},
System {
file: AbsolutePathBuf,
},
EnterpriseManaged {
id: String,
name: String,
},
User {
file: AbsolutePathBuf,
profile: Option<String>,
},
Project {
dot_codex_folder: AbsolutePathBuf,
},
SessionFlags,
LegacyManagedConfigTomlFromFile {
file: AbsolutePathBuf,
},
LegacyManagedConfigTomlFromMdm,
}Expand description
Provenance for one layer in the effective Codex configuration.
Variants
Mdm
Managed preferences delivered by MDM.
System
Host-wide configuration loaded from a file.
Fields

file: AbsolutePathBufEnterpriseManaged
Configuration delivered by an enterprise cloud bundle.
User
User configuration, optionally augmented by a selected profile.
Project
Configuration loaded from a project’s .codex directory.
Fields

dot_codex_folder: AbsolutePathBufSessionFlags
Overrides supplied for the current session.
LegacyManagedConfigTomlFromFile
Legacy managed configuration loaded from a file.
Fields

file: AbsolutePathBufLegacyManagedConfigTomlFromMdm
Legacy managed configuration delivered by MDM.
Implementations
Sourceimpl ConfigLayerSource
impl ConfigLayerSource
Sourcepub fn precedence(&self) -> i16
pub fn precedence(&self) -> i16
A setting from a layer with a higher precedence overrides a setting from a layer with a lower precedence.