pub enum McpServerTransportConfig {
Stdio {
command: String,
args: Vec<String>,
env: Option<HashMap<String, String>>,
env_vars: Vec<McpServerEnvVar>,
cwd: Option<LegacyAppPathString>,
},
StreamableHttp {
url: String,
bearer_token_env_var: Option<String>,
http_headers: Option<HashMap<String, String>>,
env_http_headers: Option<HashMap<String, String>>,
},
}Variants
Stdio
https://modelcontextprotocol.io/specification/2025-06-18/basic/transports#stdio
StreamableHttp
https://modelcontextprotocol.io/specification/2025-06-18/basic/transports#streamable-http
Fields

bearer_token_env_var: Option<String>Name of the environment variable to read for an HTTP bearer token.
When set, requests will include the token via Authorization: Bearer <token>.
The actual secret value must be provided via the environment.