ConfigLayerEntry

Struct ConfigLayerEntry 

pub struct ConfigLayerEntry {
    pub name: ConfigLayerSource,
    pub config: Value,
    pub version: String,
    pub disabled_reason: Option<String>,
    /* private fields */
}

Fields

name: ConfigLayerSourceconfig: Valueversion: Stringdisabled_reason: Option<String>

Implementations

Source

impl ConfigLayerEntry

pub fn new(name: ConfigLayerSource, config: TomlValue) -> Self

pub fn new_with_raw_toml( name: ConfigLayerSource, config: TomlValue, raw_toml: String, raw_toml_base_dir: AbsolutePathBuf, ) -> Self

pub fn new_disabled( name: ConfigLayerSource, config: TomlValue, disabled_reason: impl Into<String>, ) -> Self

pub fn is_disabled(&self) -> bool

pub fn raw_toml(&self) -> Option<&str>

pub fn raw_toml_base_dir(&self) -> Option<&AbsolutePathBuf>

pub fn metadata(&self) -> ConfigLayerMetadata

pub fn as_layer(&self) -> ConfigLayer

pub fn config_folder(&self) -> Option<AbsolutePathBuf>

pub fn hooks_config_folder(&self) -> Option<AbsolutePathBuf>

Returns the .codex/ folder that should be used for hook declarations.

Project layers normally use their own config folder. Linked Git worktrees can instead point hook discovery at the matching folder from the root checkout while the rest of the project config still comes from the worktree.