pub struct ConfigRequirementsToml {Show 30 fields
pub sqlite_home: Option<AbsolutePathBuf>,
pub log_dir: Option<AbsolutePathBuf>,
pub model_catalog_json: Option<AbsolutePathBuf>,
pub check_for_update_on_startup: Option<bool>,
pub allow_login_shell: Option<bool>,
pub feedback: Option<FeedbackConfigToml>,
pub allowed_approval_policies: Option<Vec<AskForApproval>>,
pub allowed_approvals_reviewers: Option<Vec<ApprovalsReviewer>>,
pub allowed_sandbox_modes: Option<Vec<SandboxModeRequirement>>,
pub allowed_permission_profiles: Option<BTreeMap<String, bool>>,
pub default_permissions: Option<String>,
pub remote_sandbox_config: Option<Vec<RemoteSandboxConfigToml>>,
pub allowed_web_search_modes: Option<Vec<WebSearchModeRequirement>>,
pub allow_managed_hooks_only: Option<bool>,
pub allow_appshots: Option<bool>,
pub allow_remote_control: Option<bool>,
pub computer_use: Option<ComputerUseRequirementsToml>,
pub windows: Option<WindowsRequirementsToml>,
pub feature_requirements: Option<FeatureRequirementsToml>,
pub hooks: Option<ManagedHooksRequirementsToml>,
pub mcp_servers: Option<BTreeMap<String, McpServerRequirement>>,
pub plugins: Option<BTreeMap<String, PluginRequirementsToml>>,
pub marketplaces: Option<MarketplaceRequirementsToml>,
pub apps: Option<AppsRequirementsToml>,
pub rules: Option<RequirementsExecPolicyToml>,
pub enforce_residency: Option<ResidencyRequirement>,
pub network: Option<NetworkRequirementsToml>,
pub permissions: Option<PermissionsRequirementsToml>,
pub models: Option<ModelsRequirementsToml>,
pub guardian_policy_config: Option<String>,
}Expand description
Base config deserialized from system requirements.toml or MDM.
Fields
sqlite_home: Option<AbsolutePathBuf>log_dir: Option<AbsolutePathBuf>model_catalog_json: Option<AbsolutePathBuf>check_for_update_on_startup: Option<bool>allow_login_shell: Option<bool>feedback: Option<FeedbackConfigToml>allowed_approval_policies: Option<Vec<AskForApproval>>allowed_approvals_reviewers: Option<Vec<ApprovalsReviewer>>allowed_sandbox_modes: Option<Vec<SandboxModeRequirement>>allowed_permission_profiles: Option<BTreeMap<String, bool>>default_permissions: Option<String>remote_sandbox_config: Option<Vec<RemoteSandboxConfigToml>>allowed_web_search_modes: Option<Vec<WebSearchModeRequirement>>allow_managed_hooks_only: Option<bool>allow_appshots: Option<bool>allow_remote_control: Option<bool>computer_use: Option<ComputerUseRequirementsToml>windows: Option<WindowsRequirementsToml>feature_requirements: Option<FeatureRequirementsToml>hooks: Option<ManagedHooksRequirementsToml>mcp_servers: Option<BTreeMap<String, McpServerRequirement>>plugins: Option<BTreeMap<String, PluginRequirementsToml>>marketplaces: Option<MarketplaceRequirementsToml>apps: Option<AppsRequirementsToml>rules: Option<RequirementsExecPolicyToml>enforce_residency: Option<ResidencyRequirement>network: Option<NetworkRequirementsToml>permissions: Option<PermissionsRequirementsToml>models: Option<ModelsRequirementsToml>guardian_policy_config: Option<String>Implementations
Sourceimpl ConfigRequirementsToml
impl ConfigRequirementsToml
pub fn apply_remote_sandbox_config(&mut self, hostname: Option<&str>)
pub fn is_empty(&self) -> bool
Sourcepub fn apply_exact_to_config(&self, config: &mut ConfigToml)
pub fn apply_exact_to_config(&self, config: &mut ConfigToml)
Applies the requirements whose values replace config values.
This projection is shared by config/read and config-lock export so both surfaces describe the same behavior as the final runtime config.
Sourcepub fn exact_requirement_for_config_path(
&self,
segments: &[String],
) -> Option<&'static str>
pub fn exact_requirement_for_config_path( &self, segments: &[String], ) -> Option<&'static str>
Returns the exact managed field affected by editing segments.