pub struct HookStateToml {
pub enabled: Option<bool>,
pub trusted_hash: Option<String>,
}Fields
enabled: Option<bool>trusted_hash: Option<String>Trait Implementations
Sourceimpl Clone for HookStateToml
impl Clone for HookStateToml
Sourcefn clone(&self) -> HookStateToml
fn clone(&self) -> HookStateToml
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HookStateToml
impl Debug for HookStateToml
Sourceimpl Default for HookStateToml
impl Default for HookStateToml
Sourcefn default() -> HookStateToml
fn default() -> HookStateToml
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for HookStateToml
impl<'de> Deserialize<'de> for HookStateToml
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HookStateToml
Sourceimpl JsonSchema for HookStateToml
impl JsonSchema for HookStateToml
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HookStateToml
impl PartialEq for HookStateToml
Sourceimpl Serialize for HookStateToml
impl Serialize for HookStateToml
impl StructuralPartialEq for HookStateToml