pub struct LoaderOverrides {
pub user_config_path: Option<AbsolutePathBuf>,
pub user_config_profile: Option<ProfileV2Name>,
pub managed_config_path: Option<PathBuf>,
pub system_config_path: Option<PathBuf>,
pub system_requirements_path: Option<PathBuf>,
pub ignore_managed_requirements: bool,
pub ignore_user_config: bool,
pub ignore_user_and_project_exec_policy_rules: bool,
pub macos_managed_config_requirements_base64: Option<String>,
}Expand description
LoaderOverrides overrides managed configuration inputs (primarily for tests).
Fields
user_config_path: Option<AbsolutePathBuf>user_config_profile: Option<ProfileV2Name>managed_config_path: Option<PathBuf>system_config_path: Option<PathBuf>system_requirements_path: Option<PathBuf>ignore_managed_requirements: boolignore_user_config: boolignore_user_and_project_exec_policy_rules: boolmacos_managed_config_requirements_base64: Option<String>Implementations
Sourceimpl LoaderOverrides
impl LoaderOverrides
Sourcepub fn without_managed_config_for_tests() -> Self
pub fn without_managed_config_for_tests() -> Self
Returns overrides that ignore host-managed configuration.
This is intended for tests that should load only repo-controlled config fixtures.
Sourcepub fn with_managed_config_path_for_tests(managed_config_path: PathBuf) -> Self
pub fn with_managed_config_path_for_tests(managed_config_path: PathBuf) -> Self
Returns overrides with host MDM disabled and managed config loaded from
managed_config_path. System requirements are loaded from a sibling
requirements.toml fixture.
This is intended for tests that supply an explicit managed config fixture.
pub fn user_config_path(&self, codex_home: &Path) -> Result<AbsolutePathBuf>