pub struct MatcherGroup {
pub matcher: Option<String>,
pub hooks: Vec<HookHandlerConfig>,
}Fields
matcher: Option<String>hooks: Vec<HookHandlerConfig>Trait Implementations
Sourceimpl Clone for MatcherGroup
impl Clone for MatcherGroup
Sourcefn clone(&self) -> MatcherGroup
fn clone(&self) -> MatcherGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatcherGroup
impl Debug for MatcherGroup
Sourceimpl Default for MatcherGroup
impl Default for MatcherGroup
Sourcefn default() -> MatcherGroup
fn default() -> MatcherGroup
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MatcherGroup
impl<'de> Deserialize<'de> for MatcherGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MatcherGroup
Sourceimpl JsonSchema for MatcherGroup
impl JsonSchema for MatcherGroup
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatcherGroup
impl PartialEq for MatcherGroup
Sourceimpl Serialize for MatcherGroup
impl Serialize for MatcherGroup
impl StructuralPartialEq for MatcherGroup