pub struct McpServerConfig {Show 16 fields
pub transport: McpServerTransportConfig,
pub auth: McpServerAuth,
pub environment_id: String,
pub enabled: bool,
pub required: bool,
pub supports_parallel_tool_calls: bool,
pub disabled_reason: Option<McpServerDisabledReason>,
pub startup_timeout_sec: Option<Duration>,
pub tool_timeout_sec: Option<Duration>,
pub default_tools_approval_mode: Option<AppToolApproval>,
pub enabled_tools: Option<Vec<String>>,
pub disabled_tools: Option<Vec<String>>,
pub scopes: Option<Vec<String>>,
pub oauth: Option<McpServerOAuthConfig>,
pub oauth_resource: Option<String>,
pub tools: HashMap<String, McpServerToolConfig>,
}Fields
transport: McpServerTransportConfigauth: McpServerAuthAuthentication flow to use when no configured authorization resolves.
environment_id: StringEffective environment id for where Codex should start this MCP server.
enabled: boolWhen false, Codex skips initializing this MCP server.
required: boolWhen true, codex exec exits with an error if this MCP server fails to initialize.
supports_parallel_tool_calls: boolWhen true, every tool from this server is advertised as safe for parallel tool calls.
disabled_reason: Option<McpServerDisabledReason>Reason this server was disabled after applying requirements.
startup_timeout_sec: Option<Duration>Startup timeout in seconds for initializing MCP server & initially listing tools.
tool_timeout_sec: Option<Duration>Default timeout for MCP tool calls initiated via this server.
default_tools_approval_mode: Option<AppToolApproval>Approval mode for tools in this server unless a tool override exists.
enabled_tools: Option<Vec<String>>Explicit allow-list of tools exposed from this server. When set, only these tools will be registered.
disabled_tools: Option<Vec<String>>Explicit deny-list of tools. These tools will be removed after applying enabled_tools.
scopes: Option<Vec<String>>Optional OAuth scopes to request during MCP login.
oauth: Option<McpServerOAuthConfig>Optional OAuth client settings for MCP login.
oauth_resource: Option<String>Optional OAuth resource parameter to include during MCP login (RFC 8707).
tools: HashMap<String, McpServerToolConfig>Per-tool approval settings keyed by tool name.
Implementations
Sourceimpl McpServerConfig
impl McpServerConfig
pub fn is_local_environment(&self) -> bool
pub fn oauth_client_id(&self) -> Option<&str>