pub struct RawMcpServerConfig {Show 26 fields
pub command: Option<String>,
pub args: Option<Vec<String>>,
pub env: Option<HashMap<String, String>>,
pub env_vars: Option<Vec<McpServerEnvVar>>,
pub cwd: Option<LegacyAppPathString>,
pub http_headers: Option<HashMap<String, String>>,
pub env_http_headers: Option<HashMap<String, String>>,
pub url: Option<String>,
pub bearer_token: Option<String>,
pub bearer_token_env_var: Option<String>,
pub environment_id: Option<String>,
pub auth: Option<McpServerAuth>,
pub startup_timeout_sec: Option<f64>,
pub startup_timeout_ms: Option<u64>,
pub tool_timeout_sec: Option<Duration>,
pub enabled: Option<bool>,
pub required: Option<bool>,
pub supports_parallel_tool_calls: Option<bool>,
pub default_tools_approval_mode: Option<AppToolApproval>,
pub enabled_tools: Option<Vec<String>>,
pub disabled_tools: Option<Vec<String>>,
pub scopes: Option<Vec<String>>,
pub oauth: Option<McpServerOAuthConfig>,
pub oauth_resource: Option<String>,
pub _name: Option<String>,
pub tools: Option<HashMap<String, McpServerToolConfig>>,
}Expand description
Raw MCP config shape used for deserialization and supported-field JSON Schema generation.
Fields that are accepted only to produce targeted validation errors should be skipped in the generated schema.
Keep TryFrom<RawMcpServerConfig> for McpServerConfig exhaustively
destructuring this struct so new TOML fields cannot be added here without
updating the validation/mapping logic that produces McpServerConfig.
Fields
command: Option<String>args: Option<Vec<String>>env: Option<HashMap<String, String>>env_vars: Option<Vec<McpServerEnvVar>>cwd: Option<LegacyAppPathString>http_headers: Option<HashMap<String, String>>env_http_headers: Option<HashMap<String, String>>url: Option<String>bearer_token: Option<String>bearer_token_env_var: Option<String>environment_id: Option<String>auth: Option<McpServerAuth>startup_timeout_sec: Option<f64>startup_timeout_ms: Option<u64>tool_timeout_sec: Option<Duration>enabled: Option<bool>required: Option<bool>supports_parallel_tool_calls: Option<bool>default_tools_approval_mode: Option<AppToolApproval>enabled_tools: Option<Vec<String>>disabled_tools: Option<Vec<String>>scopes: Option<Vec<String>>oauth: Option<McpServerOAuthConfig>oauth_resource: Option<String>_name: Option<String>Legacy display-name field accepted for backward compatibility.
tools: Option<HashMap<String, McpServerToolConfig>>Trait Implementations
Sourceimpl Clone for RawMcpServerConfig
impl Clone for RawMcpServerConfig
Sourcefn clone(&self) -> RawMcpServerConfig
fn clone(&self) -> RawMcpServerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RawMcpServerConfig
impl<'de> Deserialize<'de> for RawMcpServerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RawMcpServerConfig
impl JsonSchema for RawMcpServerConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl TryFrom<RawMcpServerConfig> for McpServerConfig
impl TryFrom<RawMcpServerConfig> for McpServerConfig