pub struct RequirementsExecPolicyPatternTokenToml {
pub token: Option<String>,
pub any_of: Option<Vec<String>>,
}Expand description
TOML-friendly representation of a pattern token.
Starlark supports either a string token or a list of alternative tokens at each position, but TOML arrays cannot mix strings and arrays. Using an array of tables sidesteps that restriction.
Fields
token: Option<String>any_of: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for RequirementsExecPolicyPatternTokenToml
impl Clone for RequirementsExecPolicyPatternTokenToml
Sourcefn clone(&self) -> RequirementsExecPolicyPatternTokenToml
fn clone(&self) -> RequirementsExecPolicyPatternTokenToml
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RequirementsExecPolicyPatternTokenToml
impl<'de> Deserialize<'de> for RequirementsExecPolicyPatternTokenToml
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RequirementsExecPolicyPatternTokenToml
impl StructuralPartialEq for RequirementsExecPolicyPatternTokenToml