pub struct SkillConfig {
pub path: Option<AbsolutePathBuf>,
pub name: Option<String>,
pub enabled: bool,
}Fields
path: Option<AbsolutePathBuf>Path-based selector.
name: Option<String>Name-based selector.
enabled: boolTrait Implementations
Sourceimpl Clone for SkillConfig
impl Clone for SkillConfig
Sourcefn clone(&self) -> SkillConfig
fn clone(&self) -> SkillConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SkillConfig
impl Debug for SkillConfig
Sourceimpl<'de> Deserialize<'de> for SkillConfig
impl<'de> Deserialize<'de> for SkillConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SkillConfig
Sourceimpl JsonSchema for SkillConfig
impl JsonSchema for SkillConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SkillConfig
impl PartialEq for SkillConfig
Sourceimpl Serialize for SkillConfig
impl Serialize for SkillConfig
impl StructuralPartialEq for SkillConfig