pub struct SkillsConfig {
pub bundled: Option<BundledSkillsConfig>,
pub include_instructions: Option<bool>,
pub config: Vec<SkillConfig>,
}Fields
bundled: Option<BundledSkillsConfig>include_instructions: Option<bool>Whether turns receive the automatic skills instructions block.
config: Vec<SkillConfig>Trait Implementations
Sourceimpl Clone for SkillsConfig
impl Clone for SkillsConfig
Sourcefn clone(&self) -> SkillsConfig
fn clone(&self) -> SkillsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SkillsConfig
impl Debug for SkillsConfig
Sourceimpl Default for SkillsConfig
impl Default for SkillsConfig
Sourcefn default() -> SkillsConfig
fn default() -> SkillsConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SkillsConfig
impl<'de> Deserialize<'de> for SkillsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SkillsConfig
Sourceimpl JsonSchema for SkillsConfig
impl JsonSchema for SkillsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SkillsConfig
impl PartialEq for SkillsConfig
Sourceimpl Serialize for SkillsConfig
impl Serialize for SkillsConfig
impl StructuralPartialEq for SkillsConfig