pub struct AppConfig {
pub enabled: bool,
pub approvals_reviewer: Option<ApprovalsReviewer>,
pub destructive_enabled: Option<bool>,
pub open_world_enabled: Option<bool>,
pub default_tools_approval_mode: Option<AppToolApproval>,
pub default_tools_enabled: Option<bool>,
pub tools: Option<AppToolsConfig>,
}Expand description
Config values for a single app/connector.
Fields
enabled: boolWhen false, Codex does not surface this app.
approvals_reviewer: Option<ApprovalsReviewer>Reviewer for approval prompts from this app, overriding the thread default.
destructive_enabled: Option<bool>Whether tools with destructive_hint = true are allowed for this app.
open_world_enabled: Option<bool>Whether tools with open_world_hint = true are allowed for this app.
default_tools_approval_mode: Option<AppToolApproval>Approval mode for tools in this app unless a tool override exists.
default_tools_enabled: Option<bool>Whether tools are enabled by default for this app.
tools: Option<AppToolsConfig>Per-tool settings for this app.