pub struct ExternalConfigMigrationPrompts {
pub home: Option<bool>,
pub home_last_prompted_at: Option<i64>,
pub projects: BTreeMap<String, bool>,
pub project_last_prompted_at: BTreeMap<String, i64>,
}Expand description
Settings for notices we display to users via the tui and app-server clients (primarily the Codex IDE extension). NOTE: these are different from notifications - notices are warnings, NUX screens, acknowledgements, etc.
Fields
home: Option<bool>Tracks whether home-level external config migration prompts are hidden.
home_last_prompted_at: Option<i64>Tracks the last time the home-level external config migration prompt was shown.
projects: BTreeMap<String, bool>Tracks which project paths have opted out of external config migration prompts.
project_last_prompted_at: BTreeMap<String, i64>Tracks the last time a project-level external config migration prompt was shown.