pub struct History {
pub persistence: HistoryPersistence,
pub max_bytes: Option<usize>,
}Expand description
Settings that govern if and what will be written to ~/.codex/history.jsonl.
Fields
persistence: HistoryPersistenceIf true, history entries will not be written to disk.
max_bytes: Option<usize>If set, the maximum size of the history file in bytes. The oldest entries are dropped once the file exceeds this limit.