pub struct MarketplaceConfig {
pub last_updated: Option<String>,
pub last_revision: Option<String>,
pub source_type: Option<MarketplaceSourceType>,
pub source: Option<String>,
pub ref_name: Option<String>,
pub sparse_paths: Option<Vec<String>>,
}Fields
last_updated: Option<String>Last time Codex successfully added or refreshed this marketplace.
last_revision: Option<String>Git revision Codex last successfully activated for this marketplace.
source_type: Option<MarketplaceSourceType>Source kind used to install this marketplace.
source: Option<String>Source location used when the marketplace was added.
ref_name: Option<String>Git ref to check out when source_type is git.
sparse_paths: Option<Vec<String>>Sparse checkout paths used when source_type is git.