pub struct Notice {
pub hide_full_access_warning: Option<bool>,
pub hide_world_writable_warning: Option<bool>,
pub fast_default_opt_out: Option<bool>,
pub hide_rate_limit_model_nudge: Option<bool>,
pub hide_gpt5_1_migration_prompt: Option<bool>,
pub hide_gpt_5_1_codex_max_migration_prompt: Option<bool>,
pub model_migrations: BTreeMap<String, String>,
pub external_config_migration_prompts: ExternalConfigMigrationPrompts,
}Fields
hide_full_access_warning: Option<bool>Tracks whether the user has acknowledged the full access warning prompt.
hide_world_writable_warning: Option<bool>Tracks whether the user has acknowledged the Windows world-writable directories warning.
fast_default_opt_out: Option<bool>Tracks whether the user opted out of Codex-managed fast defaults.
hide_rate_limit_model_nudge: Option<bool>Tracks whether the user opted out of the rate limit model switch reminder.
hide_gpt5_1_migration_prompt: Option<bool>Tracks whether the user has seen the model migration prompt
hide_gpt_5_1_codex_max_migration_prompt: Option<bool>Tracks whether the user has seen the gpt-5.1-codex-max migration prompt
model_migrations: BTreeMap<String, String>Tracks acknowledged model migrations as old->new model slug mappings.
external_config_migration_prompts: ExternalConfigMigrationPromptsTracks scopes where external config migration prompts should be suppressed.