pub struct OtelTlsConfig {
pub ca_certificate: Option<AbsolutePathBuf>,
pub client_certificate: Option<AbsolutePathBuf>,
pub client_private_key: Option<AbsolutePathBuf>,
}Fields
ca_certificate: Option<AbsolutePathBuf>client_certificate: Option<AbsolutePathBuf>client_private_key: Option<AbsolutePathBuf>Trait Implementations
Sourceimpl Clone for OtelTlsConfig
impl Clone for OtelTlsConfig
Sourcefn clone(&self) -> OtelTlsConfig
fn clone(&self) -> OtelTlsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OtelTlsConfig
impl Debug for OtelTlsConfig
Sourceimpl Default for OtelTlsConfig
impl Default for OtelTlsConfig
Sourcefn default() -> OtelTlsConfig
fn default() -> OtelTlsConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OtelTlsConfig
impl<'de> Deserialize<'de> for OtelTlsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OtelTlsConfig
impl JsonSchema for OtelTlsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OtelTlsConfig
impl PartialEq for OtelTlsConfig
Sourceimpl Serialize for OtelTlsConfig
impl Serialize for OtelTlsConfig
impl StructuralPartialEq for OtelTlsConfig