pub struct SandboxWorkspaceWrite {
pub writable_roots: Vec<AbsolutePathBuf>,
pub network_access: bool,
pub exclude_tmpdir_env_var: bool,
pub exclude_slash_tmp: bool,
}Fields
writable_roots: Vec<AbsolutePathBuf>network_access: boolexclude_tmpdir_env_var: boolexclude_slash_tmp: boolTrait Implementations
Sourceimpl Clone for SandboxWorkspaceWrite
impl Clone for SandboxWorkspaceWrite
Sourcefn clone(&self) -> SandboxWorkspaceWrite
fn clone(&self) -> SandboxWorkspaceWrite
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SandboxWorkspaceWrite
impl Debug for SandboxWorkspaceWrite
Sourceimpl Default for SandboxWorkspaceWrite
impl Default for SandboxWorkspaceWrite
Sourcefn default() -> SandboxWorkspaceWrite
fn default() -> SandboxWorkspaceWrite
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SandboxWorkspaceWrite
impl<'de> Deserialize<'de> for SandboxWorkspaceWrite
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SandboxWorkspaceWrite
impl JsonSchema for SandboxWorkspaceWrite
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SandboxWorkspaceWrite
impl PartialEq for SandboxWorkspaceWrite
Sourceimpl Serialize for SandboxWorkspaceWrite
impl Serialize for SandboxWorkspaceWrite
impl StructuralPartialEq for SandboxWorkspaceWrite