pub struct ToolSuggestConfig {
pub discoverables: Vec<ToolSuggestDiscoverable>,
pub disabled_tools: Vec<ToolSuggestDisabledTool>,
}Fields
discoverables: Vec<ToolSuggestDiscoverable>disabled_tools: Vec<ToolSuggestDisabledTool>Trait Implementations
Sourceimpl Clone for ToolSuggestConfig
impl Clone for ToolSuggestConfig
Sourcefn clone(&self) -> ToolSuggestConfig
fn clone(&self) -> ToolSuggestConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolSuggestConfig
impl Debug for ToolSuggestConfig
Sourceimpl Default for ToolSuggestConfig
impl Default for ToolSuggestConfig
Sourcefn default() -> ToolSuggestConfig
fn default() -> ToolSuggestConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ToolSuggestConfig
impl<'de> Deserialize<'de> for ToolSuggestConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolSuggestConfig
Sourceimpl JsonSchema for ToolSuggestConfig
impl JsonSchema for ToolSuggestConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolSuggestConfig
impl PartialEq for ToolSuggestConfig
Sourceimpl Serialize for ToolSuggestConfig
impl Serialize for ToolSuggestConfig
impl StructuralPartialEq for ToolSuggestConfig