pub struct ToolSuggestDiscoverable {
pub kind: ToolSuggestDiscoverableType,
pub id: String,
}Fields
kind: ToolSuggestDiscoverableTypeid: StringTrait Implementations
Sourceimpl Clone for ToolSuggestDiscoverable
impl Clone for ToolSuggestDiscoverable
Sourcefn clone(&self) -> ToolSuggestDiscoverable
fn clone(&self) -> ToolSuggestDiscoverable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolSuggestDiscoverable
impl Debug for ToolSuggestDiscoverable
Sourceimpl<'de> Deserialize<'de> for ToolSuggestDiscoverable
impl<'de> Deserialize<'de> for ToolSuggestDiscoverable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ToolSuggestDiscoverable
Sourceimpl Hash for ToolSuggestDiscoverable
impl Hash for ToolSuggestDiscoverable
Sourceimpl JsonSchema for ToolSuggestDiscoverable
impl JsonSchema for ToolSuggestDiscoverable
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolSuggestDiscoverable
impl PartialEq for ToolSuggestDiscoverable
Sourceimpl Serialize for ToolSuggestDiscoverable
impl Serialize for ToolSuggestDiscoverable
impl StructuralPartialEq for ToolSuggestDiscoverable