pub struct TuiComposerKeymap {
pub submit: Option<KeybindingsSpec>,
pub queue: Option<KeybindingsSpec>,
pub toggle_shortcuts: Option<KeybindingsSpec>,
pub history_search_previous: Option<KeybindingsSpec>,
pub history_search_next: Option<KeybindingsSpec>,
}Expand description
Composer context keybindings. These override corresponding global actions.
Fields
submit: Option<KeybindingsSpec>Submit the current composer draft.
queue: Option<KeybindingsSpec>Queue the current composer draft while a task is running.
toggle_shortcuts: Option<KeybindingsSpec>Toggle the composer shortcut overlay.
history_search_previous: Option<KeybindingsSpec>Open reverse history search or move to the previous match.
history_search_next: Option<KeybindingsSpec>Move to the next match in reverse history search.