pub struct TuiGlobalKeymap {
pub open_transcript: Option<KeybindingsSpec>,
pub open_external_editor: Option<KeybindingsSpec>,
pub copy: Option<KeybindingsSpec>,
pub clear_terminal: Option<KeybindingsSpec>,
pub submit: Option<KeybindingsSpec>,
pub queue: Option<KeybindingsSpec>,
pub toggle_shortcuts: Option<KeybindingsSpec>,
pub toggle_vim_mode: Option<KeybindingsSpec>,
pub toggle_fast_mode: Option<KeybindingsSpec>,
pub toggle_raw_output: Option<KeybindingsSpec>,
}Expand description
Global keybindings. These are used when a context does not define an override.
Fields
open_transcript: Option<KeybindingsSpec>Open the transcript overlay.
open_external_editor: Option<KeybindingsSpec>Open the external editor for the current draft.
copy: Option<KeybindingsSpec>Copy the last agent response to the clipboard.
clear_terminal: Option<KeybindingsSpec>Clear the terminal UI.
submit: Option<KeybindingsSpec>Submit the current composer draft.
queue: Option<KeybindingsSpec>Queue the current composer draft while a task is running.
toggle_shortcuts: Option<KeybindingsSpec>Toggle the composer shortcut overlay.
toggle_vim_mode: Option<KeybindingsSpec>Toggle Vim mode for the composer input.
toggle_fast_mode: Option<KeybindingsSpec>Toggle Fast mode.
toggle_raw_output: Option<KeybindingsSpec>Toggle raw scrollback mode for copy-friendly transcript selection.