pub struct TuiListKeymap {
pub move_up: Option<KeybindingsSpec>,
pub move_down: Option<KeybindingsSpec>,
pub move_left: Option<KeybindingsSpec>,
pub move_right: Option<KeybindingsSpec>,
pub page_up: Option<KeybindingsSpec>,
pub page_down: Option<KeybindingsSpec>,
pub jump_top: Option<KeybindingsSpec>,
pub jump_bottom: Option<KeybindingsSpec>,
pub accept: Option<KeybindingsSpec>,
pub cancel: Option<KeybindingsSpec>,
}Expand description
List selection context keybindings for popup-style selectable lists.
Fields
move_up: Option<KeybindingsSpec>Move list selection up.
move_down: Option<KeybindingsSpec>Move list selection down.
move_left: Option<KeybindingsSpec>Move horizontally left in list pickers that support horizontal actions.
move_right: Option<KeybindingsSpec>Move horizontally right in list pickers that support horizontal actions.
page_up: Option<KeybindingsSpec>Move list selection up by one page.
page_down: Option<KeybindingsSpec>Move list selection down by one page.
jump_top: Option<KeybindingsSpec>Jump to the first list item.
jump_bottom: Option<KeybindingsSpec>Jump to the last list item.
accept: Option<KeybindingsSpec>Accept current selection.
cancel: Option<KeybindingsSpec>Cancel and close selection view.