pub struct TuiVimOperatorKeymap {Show 14 fields
pub delete_line: Option<KeybindingsSpec>,
pub yank_line: Option<KeybindingsSpec>,
pub motion_left: Option<KeybindingsSpec>,
pub motion_right: Option<KeybindingsSpec>,
pub motion_up: Option<KeybindingsSpec>,
pub motion_down: Option<KeybindingsSpec>,
pub motion_word_forward: Option<KeybindingsSpec>,
pub motion_word_backward: Option<KeybindingsSpec>,
pub motion_word_end: Option<KeybindingsSpec>,
pub motion_line_start: Option<KeybindingsSpec>,
pub motion_line_end: Option<KeybindingsSpec>,
pub select_inner_text_object: Option<KeybindingsSpec>,
pub select_around_text_object: Option<KeybindingsSpec>,
pub cancel: Option<KeybindingsSpec>,
}Expand description
Vim operator-pending keybindings for modal editing inside text areas.
This context is active only while waiting for a motion after d or y.
Repeating the operator key (dd, yy) targets the entire line. Pressing
Esc cancels the pending operator and returns to normal mode without
modifying text.
Fields
delete_line: Option<KeybindingsSpec>Repeat delete operator to delete the whole line (dd).
yank_line: Option<KeybindingsSpec>Repeat yank operator to yank the whole line (yy).
motion_left: Option<KeybindingsSpec>Motion: left (h).
motion_right: Option<KeybindingsSpec>Motion: right (l).
motion_up: Option<KeybindingsSpec>Motion: up one line (k).
motion_down: Option<KeybindingsSpec>Motion: down one line (j).
motion_word_forward: Option<KeybindingsSpec>Motion: to start of next word (w).
motion_word_backward: Option<KeybindingsSpec>Motion: to start of previous word (b).
motion_word_end: Option<KeybindingsSpec>Motion: to end of current/next word (e).
motion_line_start: Option<KeybindingsSpec>Motion: to start of line (0).
motion_line_end: Option<KeybindingsSpec>Motion: to end of line ($).
select_inner_text_object: Option<KeybindingsSpec>Select an inner text object after an operator.
select_around_text_object: Option<KeybindingsSpec>Select an around text object after an operator.
cancel: Option<KeybindingsSpec>Cancel the pending operator and return to normal mode.