pub enum OAuthCredentialsStoreMode {
Auto,
File,
Keyring,
}Expand description
Determine where Codex should store and read MCP credentials.
Variants
Auto
Prefer Keyring and use File when keyring storage is unavailable.
Once an MCP client loads credentials from one store, that client keeps the resolved store
for its lifetime so refreshes cannot switch to a possibly stale credential source.
Credentials stored in the keyring will only be readable by Codex unless the user explicitly grants access via OS-level keyring access.
File
CODEX_HOME/.credentials.json This file will be readable to Codex and other applications running as the same user.
Keyring
Keyring when available, otherwise fail.